@@ -30,24 +30,28 @@
 //! fn spawn() { /* ... */ }
 //! ```
 //!
-//! 2. Insert the [`SpriteSheetAnimation`] component to the sprite sheets you want to animate
+//! 2. Create a [`SpriteSheetAnimation`] and insert the asset handle to the sprite sheet entity you want to animate
 //!
 //! ```
 //! # use std::time::Duration;
 //! # use bevy::prelude::*;
 //! # use benimator::*;
 //!
-//! fn spawn(mut commands: Commands) {
+//! fn spawn(mut commands: Commands, mut animations: ResMut<Assets<SpriteSheetAnimation>>) {
+//!
+//!     // Create an animation
+//!     let animation_handle = animations.add(SpriteSheetAnimation::from_range(
+//!         0..=2,                               // Indices of the sprite atlas
+//!         Duration::from_secs_f64(1.0 / 12.0), // Duration of each frame
+//!     ));
+//!     
 //!     commands
 //!         .spawn_bundle(SpriteSheetBundle {
 //!             // TODO: Configure the sprite sheet
 //!             ..Default::default()
 //!         })
-//!         // Insert the animation component
-//!         .insert(SpriteSheetAnimation::from_range(
-//!             0..=2,                               // Indices of the sprite atlas
-//!             Duration::from_secs_f64(1.0 / 12.0), // Duration of each frame
-//!         ))
+//!         // Insert the asset handle of the animation
+//!         .insert(animation_handle)
 //!         // Start the animation immediately
 //!         .insert(Play);
 //! }
@@ -59,28 +63,23 @@
 //!
 //! ```
 //! # use std::time::Duration;
-//! # use bevy::prelude::*;
 //! # use benimator::*;
-//! # fn spawn(mut commands: Commands) {
-//! commands
-//!     .spawn_bundle(SpriteSheetBundle { ..Default::default() })
-//!     .insert(
-//!         SpriteSheetAnimation::from_range(0..=2, Duration::from_millis(100))
-//!             .once() // <-- Runs the animation only once
-//!     )
-//!     .insert(Play); // <-- This component will be automatically removed once the animation is finished
-//! # }
+//! SpriteSheetAnimation::from_range(0..=2, Duration::from_millis(100))
+//!      .once(); // <-- Runs the animation only once
 //! ```
 //!
+//! Note that, for animations that run once, the `Play` component is automatically removed when the animation is done.
+//! So you can use the `RemovedComponents<Play>` system parameter to execute logic at the end of the animation.
+//!
 //! ## Play/Pause
 //!
-//! Animations proceed only if the [`Play`] component is in the entity.
+//! Animations proceed only if the [`Play`] component is present in the entity.
 //!
 //! To pause or resume an animation, simply remove/insert the [`Play`] component.
 //!
 //! ## Fine-grained frame-duration
 //!
-//! For more precise configuration, it is possible to define the duration of each frame:
+//! For a more precise configuration, it is possible to define the duration of each frame:
 //!
 //! ```rust
 //! # use benimator::*;
@@ -97,6 +96,7 @@
 extern crate rstest;
 
 use bevy_app::prelude::*;
+use bevy_asset::AddAsset;
 use bevy_ecs::prelude::*;
 use bevy_reflect::Reflect;
 
@@ -105,6 +105,9 @@ pub use animation::{AnimationMode, Frame, SpriteSheetAnimation};
 mod animation;
 mod state;
 
+#[cfg(feature = "warnings")]
+mod warnings;
+
 /// Plugin to enable sprite-sheet animation
 ///
 /// See crate level documentation for usage
@@ -129,8 +132,11 @@ pub struct Play;
 
 impl Plugin for AnimationPlugin {
     fn build(&self, app: &mut AppBuilder) {
-        app.register_type::<SpriteSheetAnimation>()
+        app.add_asset::<SpriteSheetAnimation>()
             .add_system_set(state::update_systems())
             .add_system_to_stage(CoreStage::PostUpdate, state::post_update_system());
+
+        #[cfg(feature = "warnings")]
+        app.add_system_set(warnings::systems());
     }
 }
